@@ -1,10 +1,12 @@
 import os
 
+from tqdm import tqdm
+
 
 def load_code_from_file(file_path):
     try:
-        return open(file_path, 'r').read()
-
+        with open(file_path, 'r') as file:
+            return file.read()
     except IOError as e:
         print('[-] Error : ' + str(e))
         return
@@ -16,9 +18,9 @@ def load_code_from_dir(dir_path):
     code_files = os.listdir(dir_path)
 
     code_dict = {}
-    for code_file in code_files:
+    for code_file in tqdm(code_files, desc="[+] Loading code files", unit='file'):
         code_path = os.path.join(dir_path, code_file)
-        # @NOTE how about "*.cpp*.cpp", how about "*.c" c99
+        # Additional handling for different file extensions can be added here
         code_file_key = code_file.replace('.cpp', '')
         code_dict[code_file_key] = load_code_from_file(code_path)
 
